jacinle.web.app
===============

.. automodule:: jacinle.web.app

   
   
   

   
   
   .. rubric:: Classes

   .. autosummary::
      :template: class.rst
   
      JacApplication
      JacRequestHandler
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
   
      get_app
      make_app
      route
   
   

   
   
   .. rubric:: Exceptions

   .. autosummary::
      :toctree:
   
      JacRequestException
   
   








.. rubric:: Class JacApplication
.. autoclass:: JacApplication
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__


.. rubric:: Class JacRequestHandler
.. autoclass:: JacRequestHandler
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__







.. rubric:: Functions

.. autofunction:: get_app

.. autofunction:: make_app

.. autofunction:: route


